==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/f6/f65f776bcb6a123e088a2df009f8a47b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticCore/Slots/imagecaption.html.twig */
class __TwigTemplate_165aefe5efa82a2233ddb3aaf5f3fc11 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<figure style=\"text-align:center;\">
    <img src=\"";
        // line 2
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl("themes/blank.png", null, null, true);
        yield "\" alt=\"An image\"/>
    <figcaption style=\"line-height:16px;padding: 5px;color:#000;font-size:16px;text-align: left;\">Your image caption goes here. You can change the position of the caption and style in the customize slot tab.</figcaption>
</figure>
<div style=\"clear:both\"></div>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticCore/Slots/imagecaption.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  45 => 2,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticCore/Slots/imagecaption.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Resources/views/Slots/imagecaption.html.twig");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/f6/f65f776bcb6a123e088a2df009f8a47b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticCore/Slots/imagecaption.html.twig */
class __TwigTemplate_165aefe5efa82a2233ddb3aaf5f3fc11 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<figure style=\"text-align:center;\">
    <img src=\"";
        // line 2
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl("themes/blank.png", null, null, true);
        yield "\" alt=\"An image\"/>
    <figcaption style=\"line-height:16px;padding: 5px;color:#000;font-size:16px;text-align: left;\">Your image caption goes here. You can change the position of the caption and style in the customize slot tab.</figcaption>
</figure>
<div style=\"clear:both\"></div>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticCore/Slots/imagecaption.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  45 => 2,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticCore/Slots/imagecaption.html.twig", "/var/www/html/production-demo/app/bundles/CoreBundle/Resources/views/Slots/imagecaption.html.twig");
    }
}
